==> netjfwatcher1.3.5_ApacheDerby.tar.gz: netjfwatcher/engine/command/control/CommandMappingTableResource.java <==
/*
 * Created on 2004/04/06
 *
 *
 * Copyright(c) 2004 Yoshimasa Matsumoto
 */
package netjfwatcher.engine.command.control;


/**
 * R}hIDIDɑΉ
 * <A HREF="{@docRoot}/suncertify/command/concrete/package-summary.html">
 * R}hۃNX</A>CX^X\R}h}bsO
 * e[ułB<BR>
 *
 * @author Yoshimasa Matsumoto
 * @version 1.0
 */
public class CommandMappingTableResource {
    /** PingĎ̎R}hID */
    public static final String PING_COMMAND_ID = "Ping";

    /** m[hĎ̎R}hID */
    public static final String NODE_INFORMATION_COMMAND_ID = "Node Information";

    /** SNMP̎R}hID */
    public static final String NODE_GET_SNMP_COMMAND_ID = "Node Get Snmp";

    /** Alarm̎R}hID */
    public static final String ALARM_INFORMATION_COMMAND_ID =
        "Alarm Information";

    /** Alarm Filter̎R}hID */
    public static final String ALARM_FILTER_COMMAND_ID = "Alarm Filter";

    /** m[hMAP̎R}hID */
    public static final String NODE_MAPLINK_COMMAND_ID = "Node MapLink";

    /** XML Socketڑԍ̎R}hID */
    public static final String XMLSOCKET_STATE_COMMAND_ID = "XML Socket state";

    /** SNMPvMIB̎ݒ̎R}hID */
    public static final String SNMP_STATISTICS_INFO_COMMAND_ID =
        "Snmp Statistics Info Get";

    /** MIB GetRequestR}hID */
    public static final String MIBGET_COMMAND_ID = "Mib Get";

    /** MIB SetRequestR}hID */
    public static final String MIBSET_COMMAND_ID = "Mib Set";

    /** SNMP System MIB̎R}hID */
    public static final String SYSTEM_MIB_GET_COMMAND_ID = "System Mib Get";

    /** SNMP Interface MIB̎R}hID */
    public static final String INTERFACE_MIB_GET_COMMAND_ID =
        "Interface Mib Get";

    /** SNMP Interface MIBf[^̎R}hID */
    public static final String INTERFACE_DATA_GET_COMMAND_ID =
        "Interface Data Get";

    /** SNMPvMIBf[^̎R}hID */
    public static final String STATISTICS_MIB_GET_COMMAND_ID =
        "Statistics Mib Get";

    /** SNMPvMIB̎ZbgR}hID */
    public static final String STATISTICS_MIB_SET_COMMAND_ID =
        "Statistics Mib Set";

    /** SNMPvMIB̎ҏWR}hID */
    public static final String STATISTICS_MIB_EDIT_COMMAND_ID =
        "Statistics Mib Edit";

    /** SNMPvMIB̎폜R}hID */
    public static final String STATISTICS_MIB_DELETE_COMMAND_ID =
        "Statistics Mib Delete";

    /** m[hǉR}hID */
    public static final String THREAD_START_COMMAND_ID = "Thread Start";

    /** m[h폜R}hID */
    public static final String THREAD_STOP_COMMAND_ID = "Thread Stop";

    /** m[hXVR}hID */
    public static final String THREAD_RESTART_COMMAND_ID = "Thread Restart";

    /** \[X̎R}hID */
    public static final String RESOURCE_GET_COMMAND_ID = "Resource Get";

    /** \[XXVR}hID */
    public static final String RESOURCE_SET_COMMAND_ID = "Resource Set";

    /** MailMR}hID */
    public static final String MAIL_SEND_TEST_COMMAND_ID = "Mail Send Test";

    /** f[^x[XvpeB̎R}hID */
    public static final String DATABASE_PROPERTY_GET_COMMAND_ID =
        "Database Prop Get";

    /** f[^x[XғR}hID */
    public static final String DATABASE_TEST_COMMAND_ID = "Database Test";

    /** ^XNXPW[ݒR}hID */
    public static final String TASK_SCHEDULE_CONTROL_COMMAND_ID =
        "TaskSchedule Control";

    /** ^XNXPW[̎R}hID */
    public static final String TASK_SCHEDULE_GET_COMMAND_ID =
        "TaskSchedule Get";

    /** ^XNXPW[ LZ R}hID */
    public static final String TASK_SCHEDULE_CANCEL_COMMAND_ID =
        "TaskSchedule Cancel";

    /** GarbageCollection R}hID */
    public static final String GARBAGECOLLECTION_COMMAND_ID =
        "GarbageCollection start";

    /** m艞R[h */
    public static final String ACK_RESPONSE = "ACK";

    /** ے艞R[h */
    public static final String NACK_RESPONSE = "NACK";
    /** FؗvR[h */
    public static final String REQUEST_AUTH_RESPONSE = "AUTH";
}

==> netjfwatcher1.3.9_ApacheDerby.tar.gz: netjfwatcher/engine/command/control/CommandMappingTableResource.java <==
/*
 * Created on 2004/04/06
 *
 *
 * Copyright(c) 2004 Yoshimasa Matsumoto
 */
package netjfwatcher.engine.command.control;


/**
 * R}hIDIDɑΉ
 * <A HREF="{@docRoot}/suncertify/command/concrete/package-summary.html">
 * R}hۃNX</A>CX^X\R}h}bsO
 * e[ułB<BR>
 *
 * @author Yoshimasa Matsumoto
 * @version 1.0
 */
public class CommandMappingTableResource {
    /** PingĎ̎R}hID */
    public static final String PING_COMMAND_ID = "Ping";

    /** m[hĎ̎R}hID */
    public static final String NODE_INFORMATION_COMMAND_ID = "Node Information";

    /** SNMP̎R}hID */
    public static final String NODE_GET_SNMP_COMMAND_ID = "Node Get Snmp";

    /** Alarm̎R}hID */
    public static final String ALARM_INFORMATION_COMMAND_ID =
        "Alarm Information";

    /** Alarm Filter̎R}hID */
    public static final String ALARM_FILTER_COMMAND_ID = "Alarm Filter";

    /** m[hMAP̎R}hID */
    public static final String NODE_MAPLINK_COMMAND_ID = "Node MapLink";

    /** XML Socketڑԍ̎R}hID */
    public static final String XMLSOCKET_STATE_COMMAND_ID = "XML Socket state";

    /** SNMPvMIB̎ݒ̎R}hID */
    public static final String SNMP_STATISTICS_INFO_COMMAND_ID =
        "Snmp Statistics Info Get";

    /** MIB GetRequestR}hID */
    public static final String MIBGET_COMMAND_ID = "Mib Get";

    /** MIB SetRequestR}hID */
    public static final String MIBSET_COMMAND_ID = "Mib Set";

    /** SNMP System MIB̎R}hID */
    public static final String SYSTEM_MIB_GET_COMMAND_ID = "System Mib Get";

    /** SNMP Interface MIB̎R}hID */
    public static final String INTERFACE_MIB_GET_COMMAND_ID =
        "Interface Mib Get";

    /** SNMP Interface MIBf[^̎R}hID */
    public static final String INTERFACE_DATA_GET_COMMAND_ID =
        "Interface Data Get";

    /** SNMPvMIBf[^̎R}hID */
    public static final String STATISTICS_MIB_GET_COMMAND_ID =
        "Statistics Mib Get";

    /** SNMPvMIB̎ZbgR}hID */
    public static final String STATISTICS_MIB_SET_COMMAND_ID =
        "Statistics Mib Set";

    /** SNMPvMIB̎ҏWR}hID */
    public static final String STATISTICS_MIB_EDIT_COMMAND_ID =
        "Statistics Mib Edit";

    /** SNMPvMIB̎폜R}hID */
    public static final String STATISTICS_MIB_DELETE_COMMAND_ID =
        "Statistics Mib Delete";

    /** m[hǉR}hID */
    public static final String THREAD_START_COMMAND_ID = "Thread Start";

    /** m[h폜R}hID */
    public static final String THREAD_STOP_COMMAND_ID = "Thread Stop";

    /** m[hXVR}hID */
    public static final String THREAD_RESTART_COMMAND_ID = "Thread Restart";

    /** \[X̎R}hID */
    public static final String RESOURCE_GET_COMMAND_ID = "Resource Get";

    /** \[XXVR}hID */
    public static final String RESOURCE_SET_COMMAND_ID = "Resource Set";

    /** MailMR}hID */
    public static final String MAIL_SEND_TEST_COMMAND_ID = "Mail Send Test";

    /** f[^x[XvpeB̎R}hID */
    public static final String DATABASE_PROPERTY_GET_COMMAND_ID =
        "Database Prop Get";

    /** f[^x[XғR}hID */
    public static final String DATABASE_TEST_COMMAND_ID = "Database Test";

    /** ^XNXPW[ݒR}hID */
    public static final String TASK_SCHEDULE_CONTROL_COMMAND_ID =
        "TaskSchedule Control";

    /** ^XNXPW[̎R}hID */
    public static final String TASK_SCHEDULE_GET_COMMAND_ID =
        "TaskSchedule Get";

    /** ^XNXPW[ LZ R}hID */
    public static final String TASK_SCHEDULE_CANCEL_COMMAND_ID =
        "TaskSchedule Cancel";

    /** GarbageCollection R}hID */
    public static final String GARBAGECOLLECTION_COMMAND_ID =
        "GarbageCollection start";

    /** Network Printer R}hID */
    public static final String NETWORK_PRINTER_COMMAND_ID =
        "Network Printer";
    
    /** Network Camera R}hID */
    public static final String NETWORK_CAMERA_COMMAND_ID =
        "Network Camera";
    
    /** m艞R[h */
    public static final String ACK_RESPONSE = "ACK";

    /** ے艞R[h */
    public static final String NACK_RESPONSE = "NACK";
    /** FؗvR[h */
    public static final String REQUEST_AUTH_RESPONSE = "AUTH";
}
